# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atyp',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/atyp',
                'lib_path': 'atyp'},
  'syms': { 'atyp.atyp': {},
            'atyp.biol': {},
            'atyp.bool': {},
            'atyp.btyp': {},
            'atyp.byte': {},
            'atyp.clsv': {},
            'atyp.cstm': {},
            'atyp.ctyp': {},
            'atyp.data': {},
            'atyp.dtyp': {},
            'atyp.enum': {},
            'atyp.imgs': {},
            'atyp.imps': {},
            'atyp.insp': {},
            'atyp.iter': {},
            'atyp.ityp': {},
            'atyp.list': {},
            'atyp.logr': {},
            'atyp.mtyp': {},
            'atyp.nums': {},
            'atyp.path': {},
            'atyp.plot': {},
            'atyp.ptyp': {},
            'atyp.qtyp': {},
            'atyp.rich': {},
            'atyp.rtyp': {},
            'atyp.sets': {},
            'atyp.strs': {},
            'atyp.tens': {},
            'atyp.tgrd': {},
            'atyp.type': {},
            'atyp.typq': {},
            'atyp.typr': {},
            'atyp.ztyp': {}}}
